---
title: utils
---

::: pyslurm.utils
    options:
        members: []

::: pyslurm.utils.timestr_to_secs
::: pyslurm.utils.timestr_to_mins
::: pyslurm.utils.secs_to_timestr
::: pyslurm.utils.mins_to_timestr
::: pyslurm.utils.date_to_timestamp
::: pyslurm.utils.timestamp_to_date
::: pyslurm.utils.expand_range_str
::: pyslurm.utils.humanize
::: pyslurm.utils.dehumanize
::: pyslurm.utils.nodelist_from_range_str
::: pyslurm.utils.nodelist_to_range_str
